@@ -1,6 +1,5 @@
 import * as React from 'react';
 import { shallow } from 'enzyme';
-import { EmptyState, Title } from '@patternfly/react-core';
 
 import { GraphEmpty } from '@console/internal/components/graphs/graph-empty';
 
@@ -12,7 +11,7 @@ describe('<GraphEmpty />', () => {
 
   it('should render an empty state', () => {
     const wrapper = shallow(<GraphEmpty />);
-    expect(wrapper.find(EmptyState).exists()).toBe(true);
-    expect(wrapper.find(Title).exists()).toBe(true);
+    expect(wrapper.find('.text-secondary').exists()).toBe(true);
+    expect(wrapper.text()).toEqual('No datapoints found.');
   });
 });
