@@ -15,9 +15,10 @@ import {
 
 const tap = !!process.env.TAP;
 
+export const BROWSER_NAME = process.env.BRIDGE_E2E_BROWSER_NAME || 'chrome';
 export const BROWSER_TIMEOUT = 15000;
-export const JASMSPEC_TIMEOUT = process.env.JASMINE_TIMEOUT
-  ? Number(process.env.JASMINE_TIMEOUT)
+export const JASMSPEC_TIMEOUT = process.env.BRIDGE_JASMINE_TIMEOUT
+  ? Number(process.env.BRIDGE_JASMINE_TIMEOUT)
   : 120000;
 export const appHost = `${process.env.BRIDGE_BASE_ADDRESS || 'http://localhost:9000'}${(
   process.env.BRIDGE_BASE_PATH || '/'
@@ -32,10 +33,11 @@ const htmlReporter = new HtmlScreenshotReporter({
   dest: `./${screenshotsDir}`,
   inlineImages: true,
   captureOnlyFailedSpecs: true,
-  filename: 'test-gui-report.html',
+  filename: 'protractor-report.html',
 });
 const junitReporter = new JUnitXmlReporter({
   savePath: `./${screenshotsDir}`,
+  filePrefix: 'junit_protractor',
   consolidateAll: true,
 });
 const browserLogs = [];
@@ -99,6 +101,7 @@ const testSuites = {
     'tests/dashboards/cluster-dashboard.scenario.ts',
     'tests/dashboards/project-dashboard.scenario.ts',
     'tests/event.scenario.ts',
+    'tests/cluster-settings.scenario.ts',
   ]),
   release: suite([
     'tests/crud.scenario.ts',
@@ -135,6 +138,7 @@ const testSuites = {
     'tests/dashboards/cluster-dashboard.scenario.ts',
     'tests/dashboards/project-dashboard.scenario.ts',
     'tests/event.scenario.ts',
+    'tests/cluster-settings.scenario.ts',
   ]),
   clusterSettings: suite(['tests/cluster-settings.scenario.ts']),
   alertmanager: suite(['tests/alertmanager.scenario.ts']),
@@ -156,7 +160,7 @@ export const config = {
   logLevel: tap ? 'ERROR' : 'INFO',
   plugins: process.env.NO_FAILFAST ? [] : [failFast.init()],
   capabilities: {
-    browserName: 'chrome',
+    browserName: BROWSER_NAME,
     acceptInsecureCerts: true,
     chromeOptions: {
       // A path to chrome binary, if undefined will use system chrome browser.
