@@ -40,7 +40,11 @@ const EventItem: React.FC<EventItemProps> = React.memo(({ event, isExpanded, onT
             </div>
             <div className="co-recent-item__title-message">
               {isWarning && (
-                <YellowExclamationTriangleIcon className="co-dashboard-icon co-recent-item__icon--warning" />
+                <YellowExclamationTriangleIcon
+                  alt="Warning"
+                  title="Warning"
+                  className="co-dashboard-icon co-recent-item__icon--warning"
+                />
               )}
               {!expanded && (
                 <>
