@@ -27,3 +27,7 @@ export const K8S_UI_SCHEMA = {
 
 export const JSON_SCHEMA_GROUP_TYPES: string[] = ['object', 'array'];
 export const JSON_SCHEMA_NUMBER_TYPES: string[] = ['number', 'integer'];
+
+export const THOUSAND = 10 ** 3;
+export const MILLION = 10 ** 6;
+export const BILLION = 10 ** 9;
