@@ -3,7 +3,7 @@ import { PlusCircleIcon } from '@patternfly/react-icons';
 import { Button } from '@patternfly/react-core';
 
 export interface MultiColumnFieldHeader {
-  addLabel: string;
+  addLabel?: string;
   onAdd: () => void;
   disableAddRow?: boolean;
 }
