@@ -1,6 +1,6 @@
 import * as _ from 'lodash';
 import { K8sResourceKind } from '@console/internal/module/k8s';
-import { DeploymentConfigModel } from '@console/internal/models';
+import { DeploymentConfigModel, PodModel } from '@console/internal/models';
 import { RevisionModel } from '@console/knative-plugin';
 import * as utils from '../pod-utils';
 import { usePodScalingAccessStatus, podRingLabel, getFailedPods } from '../pod-ring-utils';
@@ -171,6 +171,14 @@ describe('usePodScalingAccessStatus', () => {
     });
   });
 
+  it('should return false for pods', (done) => {
+    obj.kind = 'Pod';
+    testHook(() => {
+      expect(usePodScalingAccessStatus(obj, PodModel, [], true)).toBe(false);
+      done();
+    });
+  });
+
   it('should return false when api call returns false for a resource', (done) => {
     obj.kind = 'DeploymentConfig';
     testHook(() => {
