@@ -242,24 +242,28 @@ export const usePodScalingAccessStatus = (
   enableScaling?: boolean,
   impersonate?: string,
 ) => {
-  const [editable, setEditable] = useSafetyFirst(false);
-  React.useEffect(() => {
-    checkPodEditAccess(obj, resourceKind, impersonate)
-      .then((resp: SelfSubjectAccessReviewKind) =>
-        setEditable(_.get(resp, 'status.allowed', false)),
-      )
-      .catch((error) => {
-        // console.log is used here instead of throw error
-        // throw error will break the thread and likely end-up in a white screen
-        // eslint-disable-next-line
-        console.log(error);
-        setEditable(false);
-      });
-  }, [pods, obj, resourceKind, impersonate, setEditable]);
-
   const isKnativeRevision = obj.kind === 'Revision';
-  const isScalingAllowed = !isKnativeRevision && editable && enableScaling;
-  return isScalingAllowed;
+  const isPod = obj.kind === 'Pod';
+  const isScalingAllowed = !isKnativeRevision && !isPod && enableScaling;
+  const [editable, setEditable] = useSafetyFirst(false);
+
+  React.useEffect(() => {
+    if (isScalingAllowed) {
+      checkPodEditAccess(obj, resourceKind, impersonate)
+        .then((resp: SelfSubjectAccessReviewKind) =>
+          setEditable(_.get(resp, 'status.allowed', false)),
+        )
+        .catch((error) => {
+          // console.log is used here instead of throw error
+          // throw error will break the thread and likely end-up in a white screen
+          // eslint-disable-next-line
+          console.log(error);
+          setEditable(false);
+        });
+    }
+  }, [pods, obj, resourceKind, impersonate, setEditable, isScalingAllowed]);
+
+  return editable;
 };
 
 export const transformPodRingData = (resources: PodRingResources, kind: string): PodRingData => {
