@@ -369,7 +369,7 @@ export const gitImportInitialValues: GitImportFormData = {
     disable: true,
     create: true,
     targetPort: '8080-tcp',
-    unknownTargetPort: '',
+    unknownTargetPort: '8080',
     defaultUnknownPort: 8080,
     path: '',
     hostname: 'nationalparks-py-div.apps.rorai-cluster34.devcluster.openshift.com',
@@ -443,13 +443,14 @@ export const gitImportInitialValues: GitImportFormData = {
 export const externalImageValues: DeployImageFormData = {
   formType: 'edit',
   name: 'nationalparks-py',
-  application: { name: '', selectedKey: '#UNASSIGNED_KEY#' },
+  application: { name: '', selectedKey: UNASSIGNED_KEY },
   project: { name: 'div' },
+  runtimeIcon: 'python',
   route: {
     disable: true,
     create: true,
     targetPort: '8080-tcp',
-    unknownTargetPort: '',
+    unknownTargetPort: '8080',
     defaultUnknownPort: 8080,
     path: '',
     hostname: 'nationalparks-py-div.apps.rorai-cluster34.devcluster.openshift.com',
@@ -495,6 +496,7 @@ export const externalImageValues: DeployImageFormData = {
   },
   searchTerm: undefined,
   registry: 'external',
+  allowInsecureRegistry: false,
   imageStream: { image: '', tag: '', namespace: '', grantAccess: true },
   isi: {
     name: '',
@@ -518,13 +520,14 @@ export const externalImageValues: DeployImageFormData = {
 export const internalImageValues: DeployImageFormData = {
   formType: 'edit',
   name: 'nationalparks-py',
-  application: { name: '', selectedKey: '#UNASSIGNED_KEY#' },
+  application: { name: '', selectedKey: UNASSIGNED_KEY },
   project: { name: 'div' },
+  runtimeIcon: 'python',
   route: {
     disable: true,
     create: true,
     targetPort: '8080-tcp',
-    unknownTargetPort: '',
+    unknownTargetPort: '8080',
     defaultUnknownPort: 8080,
     path: '',
     hostname: 'nationalparks-py-div.apps.rorai-cluster34.devcluster.openshift.com',
@@ -570,6 +573,7 @@ export const internalImageValues: DeployImageFormData = {
   },
   searchTerm: '',
   registry: 'internal',
+  allowInsecureRegistry: false,
   imageStream: { image: 'python', tag: '3.6', namespace: 'div' },
   isi: {
     name: '',
@@ -614,7 +618,7 @@ export const knAppResources: AppResources = {
 };
 
 export const knExternalImageValues: DeployImageFormData = {
-  application: { name: '', selectedKey: '#UNASSIGNED_KEY#' },
+  application: { name: '', selectedKey: UNASSIGNED_KEY },
   build: { env: [], strategy: '', triggers: {} },
   deployment: { env: [], replicas: 1, triggers: { image: false } },
   formType: 'edit',
@@ -644,6 +648,7 @@ export const knExternalImageValues: DeployImageFormData = {
   name: 'nationalparks-py',
   pipeline: { enabled: false },
   project: { name: 'div' },
+  runtimeIcon: null,
   registry: 'external',
   resources: Resources.KnativeService,
   route: {
@@ -665,6 +670,7 @@ export const knExternalImageValues: DeployImageFormData = {
     unknownTargetPort: '',
   },
   searchTerm: 'openshift/hello-openshift',
+  allowInsecureRegistry: false,
   serverless: { scaling: { concurrencylimit: '', concurrencytarget: '', maxpods: '', minpods: 0 } },
   healthChecks: healthChecksProbeInitialData,
 };
