@@ -34,7 +34,11 @@ describe('Import Submit Utils', () => {
       const annotations = _.get(returnValue, 'data.metadata.annotations');
       expect(JSON.parse(annotations['image.openshift.io/triggers'])).toEqual([
         {
-          from: { kind: 'ImageStreamTag', name: 'nodejs-ex-git:latest' },
+          from: {
+            kind: 'ImageStreamTag',
+            name: 'nodejs-ex-git:latest',
+            namespace: 'gijohn',
+          },
           fieldPath: 'spec.template.spec.containers[?(@.name=="nodejs-ex-git")].image',
           pause: 'false',
         },
