@@ -1,24 +1,14 @@
 import * as React from 'react';
 import { SectionHeading, ResourceSummary } from '@console/internal/components/utils';
-import { TriggerBindingModel, TriggerTemplateModel } from '../../../models';
 import { EventListenerKind } from '../resource-types';
-import DynamicResourceLinkList, {
-  ResourceModelLink,
-} from '../resource-overview/DynamicResourceLinkList';
-import TriggerTemplateResourceLink from '../resource-overview/TriggerTemplateResourceLink';
-import {
-  RouteTemplate,
-  useEventListenerTriggerTemplateNames,
-  getEventListenerTriggerBindingNames,
-} from '../utils/triggers';
+import EventListenerURL from './EventListenerURL';
+import EventListenerTriggers from './EventListenerTriggers';
 
 export interface EventListenerDetailsProps {
   obj: EventListenerKind;
 }
 
 const EventListenerDetails: React.FC<EventListenerDetailsProps> = ({ obj: eventListener }) => {
-  const routeTemplates: RouteTemplate[] = useEventListenerTriggerTemplateNames(eventListener) || [];
-  const bindings: ResourceModelLink[] = getEventListenerTriggerBindingNames(eventListener);
   return (
     <div className="co-m-pane__body">
       <SectionHeading text="Event Listener Details" />
@@ -27,15 +17,13 @@ const EventListenerDetails: React.FC<EventListenerDetailsProps> = ({ obj: eventL
           <ResourceSummary resource={eventListener} />
         </div>
         <div className="col-sm-6">
-          <TriggerTemplateResourceLink
+          <EventListenerURL
+            eventListener={eventListener}
             namespace={eventListener.metadata.namespace}
-            model={TriggerTemplateModel}
-            links={routeTemplates}
           />
-          <DynamicResourceLinkList
-            links={bindings}
+          <EventListenerTriggers
             namespace={eventListener.metadata.namespace}
-            title={TriggerBindingModel.labelPlural}
+            triggers={eventListener.spec.triggers}
           />
         </div>
       </div>
