@@ -98,14 +98,14 @@ export const sbrBackingServiceSelectors: Partial<TopologyDataResources> = {
             {
               group: 'postgresql.baiju.dev',
               version: 'v1alpha1',
-              kind: 'Database',
-              name: 'db-demo1',
+              kind: 'Jaeger',
+              name: 'jaeger-all-in-one-inmemory',
             },
             {
               group: 'postgresql.baiju.dev',
               version: 'v1alpha1',
-              kind: 'Database',
-              name: 'db-demo2',
+              kind: 'Jaeger',
+              name: 'jaeger-all-in-one-inmemory',
             },
           ],
           detectBindingResources: true,
@@ -167,8 +167,8 @@ export const sbrBackingServiceSelector: Partial<TopologyDataResources> = {
             {
               group: 'postgresql.baiju.dev',
               version: 'v1alpha1',
-              kind: 'Database',
-              name: 'db-demo1',
+              kind: 'Jaeger',
+              name: 'jaeger-all-in-one-inmemory',
             },
           ],
           detectBindingResources: true,
