@@ -38,6 +38,7 @@ export interface TaskStatus {
   Succeeded: number;
   Cancelled: number;
   Failed: number;
+  Skipped: number;
 }
 
 export interface PipelineTaskRef {
@@ -67,6 +68,11 @@ export interface PipelineTaskResource {
   resource?: string;
   from?: string[];
 }
+export interface WhenExpression {
+  Input: string;
+  Operator: string;
+  Values: string[];
+}
 export interface PipelineTask {
   name: string;
   runAfter?: string[];
@@ -75,6 +81,7 @@ export interface PipelineTask {
   params?: PipelineTaskParam[];
   resources?: PipelineTaskResources;
   workspaces?: PipelineTaskWorkspace[];
+  when?: WhenExpression[];
 }
 export interface PipelineTaskWorkspace {
   name: string;
@@ -178,6 +185,9 @@ export interface PipelineRun extends K8sResourceKind {
     startTime?: string;
     completionTime?: string;
     taskRuns?: PLRTaskRuns;
+    skippedTasks?: {
+      name: string;
+    }[];
   };
 }
 
@@ -404,6 +414,7 @@ export const getTaskStatus = (pipelinerun: PipelineRun, pipeline: Pipeline): Tas
       ? Object.keys(pipelinerun.status.taskRuns)
       : [];
   const plrTaskLength = plrTasks.length;
+  const skippedTaskLength = (pipelinerun?.status?.skippedTasks || []).length;
   const taskStatus: TaskStatus = {
     PipelineNotStarted: 0,
     Pending: 0,
@@ -411,6 +422,7 @@ export const getTaskStatus = (pipelinerun: PipelineRun, pipeline: Pipeline): Tas
     Succeeded: 0,
     Failed: 0,
     Cancelled: 0,
+    Skipped: skippedTaskLength,
   };
   if (pipelinerun && pipelinerun.status && pipelinerun.status.taskRuns) {
     plrTasks.forEach((taskRun) => {
@@ -430,7 +442,8 @@ export const getTaskStatus = (pipelinerun: PipelineRun, pipeline: Pipeline): Tas
 
     const pipelineRunHasFailure = taskStatus[runStatus.Failed] > 0;
     const pipelineRunIsCancelled = pipelineRunFilterReducer(pipelinerun) === runStatus.Cancelled;
-    const unhandledTasks = totalTasks >= plrTaskLength ? totalTasks - plrTaskLength : totalTasks;
+    const unhandledTasks =
+      totalTasks >= plrTaskLength ? totalTasks - plrTaskLength - skippedTaskLength : totalTasks;
 
     if (pipelineRunHasFailure || pipelineRunIsCancelled) {
       taskStatus[runStatus.Cancelled] += unhandledTasks;
