@@ -4,9 +4,20 @@ import { KebabAction } from '@console/internal/components/utils';
 import { EditApplication } from '@console/dev-console/src/actions/modify-application';
 import { AddHealthChecks, EditHealthChecks } from '@console/app/src/actions/modify-health-checks';
 import { setTrafficDistribution } from '../actions/traffic-splitting';
+import { addTrigger } from '../actions/add-trigger';
+import { addSubscription } from '../actions/add-subscription';
 import { setSinkSource } from '../actions/sink-source';
-import { ServiceModel } from '../models';
-import { getDynamicEventSourcesModelRefs } from './fetch-dynamic-eventsources-utils';
+import { setSinkPubsub } from '../actions/sink-pubsub';
+import {
+  ServiceModel,
+  EventingSubscriptionModel,
+  EventingTriggerModel,
+  EventingBrokerModel,
+} from '../models';
+import {
+  getDynamicEventSourcesModelRefs,
+  isEventingChannelResourceKind,
+} from './fetch-dynamic-eventsources-utils';
 
 export const getKebabActionsForKind = (resourceKind: K8sKind): KebabAction[] => {
   const menuActions: KebabAction[] = [];
@@ -18,6 +29,18 @@ export const getKebabActionsForKind = (resourceKind: K8sKind): KebabAction[] =>
     if (_.includes(eventSourceModelrefs, referenceForModel(resourceKind))) {
       menuActions.push(setSinkSource);
     }
+    if (
+      referenceForModel(resourceKind) === referenceForModel(EventingSubscriptionModel) ||
+      referenceForModel(resourceKind) === referenceForModel(EventingTriggerModel)
+    ) {
+      menuActions.push(setSinkPubsub);
+    }
+    if (referenceForModel(resourceKind) === referenceForModel(EventingBrokerModel)) {
+      menuActions.push(addTrigger);
+    }
+    if (isEventingChannelResourceKind(referenceForModel(resourceKind))) {
+      menuActions.push(addSubscription);
+    }
   }
   return menuActions;
 };
