@@ -21,7 +21,7 @@ export const templateSelect = $('#template-dropdown');
 export const provisionSourceSelect = $('#image-source-type-dropdown');
 const provisionSourceURL = $('#provision-source-url');
 const provisionSourceContainerImage = $('#provision-source-container');
-export const provisionSources = {
+export const provisionSourceInputs = {
   URL: provisionSourceURL,
   Container: provisionSourceContainerImage,
 };
@@ -47,9 +47,6 @@ export const storageBootSourceSelect = $('#storage-bootsource');
 export const diskWarning = (resourceName) =>
   $(`[data-id="${resourceName}"]`).$('.kubevirt-validation-cell__cell--warning');
 
-// Virtual Hardware tab
-export const addCDButton = $('#vm-cd-add-btn');
-
 // Advanced -- Cloud-init
 export const cloudInitFormCheckbox = $('#cloud-init-edit-mode-first-option');
 export const cloudInitCustomScriptCheckbox = $('#cloud-init-edit-mode-second-option');
@@ -80,8 +77,9 @@ export const clickKebabAction = async (resourceName: string, actionLabel: string
   await click(actionForLabel(actionLabel));
 };
 
-export const tableRowAttribute = async (dataId: string, columnIndex: number): Promise<string> => {
-  return $(`tr[data-id="${dataId}"]`)
+export const tableRow = (name: string) => $(`tr[data-id="${name}"]`);
+export const tableRowAttribute = async (name: string, columnIndex: number): Promise<string> => {
+  return tableRow(name)
     .$$('td')
     .get(columnIndex)
     .getText();
