@@ -1,4 +1,5 @@
-import { apiVersionForModel, K8sResourceCommon } from '@console/internal/module/k8s';
+import * as _ from 'lodash';
+import { apiVersionForModel, K8sResourceCommon, Toleration } from '@console/internal/module/k8s';
 import { LocalVolumeDiscovery as AutoDetectVolumeModel } from '../../models';
 import { DISCOVERY_CR_NAME, HOSTNAME_LABEL_KEY, LABEL_OPERATOR } from '../../constants';
 import { getNodes, getHostNames } from '../../utils';
@@ -10,15 +11,17 @@ export const getDiscoveryRequestData = ({
   showNodesListOnADV,
   hostNamesMapForADV,
   ns,
+  toleration,
 }: {
   nodeNamesForLVS: string[];
   allNodeNamesOnADV: string[];
   showNodesListOnADV: boolean;
   hostNamesMapForADV: HostNamesMap;
   ns: string;
+  toleration?: Toleration;
 }): AutoDetectVolumeKind => {
   const nodes = getNodes(showNodesListOnADV, allNodeNamesOnADV, nodeNamesForLVS);
-  return {
+  const request: AutoDetectVolumeKind = {
     apiVersion: apiVersionForModel(AutoDetectVolumeModel),
     kind: AutoDetectVolumeModel.kind,
     metadata: { name: DISCOVERY_CR_NAME, namespace: ns },
@@ -38,6 +41,8 @@ export const getDiscoveryRequestData = ({
       },
     },
   };
+  if (!_.isEmpty(toleration)) request.spec.tolerations = [toleration];
+  return request;
 };
 
 type AutoDetectVolumeKind = K8sResourceCommon & {
@@ -49,5 +54,6 @@ type AutoDetectVolumeKind = K8sResourceCommon & {
         },
       ];
     };
+    tolerations?: Toleration[];
   };
 };
