@@ -81,7 +81,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/network-attachment-definitions/NetworkAttachmentDefinitionCreateYaml' /* webpackChunkName: "network-attachment-definitions" */
         ).then((m) => m.default),
-      required: FLAG_NET_ATTACH_DEF,
+    },
+    flags: {
+      required: [FLAG_NET_ATTACH_DEF],
     },
   },
   {
@@ -100,7 +102,9 @@ const plugin: Plugin<ConsumedExtensions> = [
         import(
           './components/network-attachment-definitions/NetworkAttachmentDefinitionsForm' /* webpackChunkName: "network-attachment-definitions" */
         ).then((m) => m.default),
-      required: FLAG_NET_ATTACH_DEF,
+    },
+    flags: {
+      required: [FLAG_NET_ATTACH_DEF],
     },
   },
 ];
