@@ -1,5 +1,6 @@
 import * as _ from 'lodash';
 import * as React from 'react';
+import cx from 'classnames';
 import DashboardCard from '@console/shared/src/components/dashboard/dashboard-card/DashboardCard';
 import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
 import DashboardCardHeader from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardHeader';
@@ -7,7 +8,7 @@ import DashboardCardLink from '@console/shared/src/components/dashboard/dashboar
 import DashboardCardTitle from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardTitle';
 import DetailsBody from '@console/shared/src/components/dashboard/details-card/DetailsBody';
 import DetailItem from '@console/shared/src/components/dashboard/details-card/DetailItem';
-import { getName, getRequester } from '@console/shared';
+import { getName, getRequester, GreenCheckCircleIcon } from '@console/shared';
 import { LabelList, resourcePathFromModel } from '../../utils';
 import { ProjectModel } from '../../../models';
 import { ProjectDashboardContext } from './project-dashboard-context';
@@ -17,7 +18,9 @@ export const DetailsCard: React.FC = () => {
   const keys = _.keys(obj.metadata.labels).sort();
   const labelsSubset = _.take(keys, 3);
   const firstThreelabels = _.pick(obj.metadata.labels, labelsSubset);
+  const description = obj.metadata.annotations?.['openshift.io/description'];
   const detailsLink = `${resourcePathFromModel(ProjectModel, obj.metadata.name)}/details`;
+  const serviceMeshEnabled = obj.metadata?.labels?.['maistra.io/member-of'];
   return (
     <DashboardCard data-test-id="details-card">
       <DashboardCardHeader>
@@ -38,6 +41,21 @@ export const DetailsCard: React.FC = () => {
               {keys.length > 3 && <DashboardCardLink to={detailsLink}>View all</DashboardCardLink>}
             </div>
           </DetailItem>
+          <DetailItem isLoading={!obj} title="Description">
+            <span
+              className={cx({
+                'text-muted': !description,
+                'co-project-dashboard-details-card__description': description,
+              })}
+            >
+              {description || 'No description'}
+            </span>
+          </DetailItem>
+          {serviceMeshEnabled && (
+            <DetailItem isLoading={!obj} title="Service Mesh">
+              <GreenCheckCircleIcon /> Service Mesh Enabled
+            </DetailItem>
+          )}
         </DetailsBody>
       </DashboardCardBody>
     </DashboardCard>
