@@ -28,9 +28,11 @@ import { FirehoseResult, FirehoseResource, useAccessReview } from '../../utils';
 import { K8sKind, referenceForModel } from '../../../module/k8s';
 import { getName } from '@console/shared';
 import { ProjectDashboardContext } from './project-dashboard-context';
-import { connectToFlags, FlagsObject } from '../../../reducers/features';
-import * as plugins from '../../../plugins';
-import { isProjectDashboardInventoryItem } from '@console/plugin-sdk';
+import {
+  useExtensions,
+  ProjectDashboardInventoryItem,
+  isProjectDashboardInventoryItem,
+} from '@console/plugin-sdk';
 
 const createFirehoseResource = (model: K8sKind, projectName: string): FirehoseResource => ({
   kind: model.crd ? referenceForModel(model) : model.kind,
@@ -102,15 +104,10 @@ const ProjectInventoryItem = withDashboardResources(
   },
 );
 
-const getPluginItems = (flags: FlagsObject) =>
-  plugins.registry
-    .getProjectDashboardInventoryItems()
-    .filter((e) => plugins.registry.isExtensionInUse(e, flags));
-
-export const InventoryCard = connectToFlags(
-  ...plugins.registry.getGatingFlagNames([isProjectDashboardInventoryItem]),
-)(({ flags }) => {
-  const pluginItems = getPluginItems(flags);
+export const InventoryCard = () => {
+  const itemExtensions = useExtensions<ProjectDashboardInventoryItem>(
+    isProjectDashboardInventoryItem,
+  );
   const { obj } = React.useContext(ProjectDashboardContext);
   const projectName = getName(obj);
   const canListSecrets = useAccessReview({
@@ -119,8 +116,9 @@ export const InventoryCard = connectToFlags(
     namespace: projectName,
     verb: 'list',
   });
+
   return (
-    <DashboardCard>
+    <DashboardCard data-test-id="inventory-card">
       <DashboardCardHeader>
         <DashboardCardTitle>Inventory</DashboardCardTitle>
       </DashboardCardHeader>
@@ -143,7 +141,7 @@ export const InventoryCard = connectToFlags(
         <ProjectInventoryItem projectName={projectName} model={RouteModel} />
         <ProjectInventoryItem projectName={projectName} model={ConfigMapModel} />
         {canListSecrets && <ProjectInventoryItem projectName={projectName} model={SecretModel} />}
-        {pluginItems.map((item) => (
+        {itemExtensions.map((item) => (
           <ProjectInventoryItem
             key={item.properties.model.kind}
             projectName={projectName}
@@ -156,7 +154,7 @@ export const InventoryCard = connectToFlags(
       </DashboardCardBody>
     </DashboardCard>
   );
-});
+};
 
 type ProjectInventoryItemProps = DashboardItemProps & {
   projectName: string;
