@@ -2,8 +2,7 @@ import * as React from 'react';
 import { connect } from 'react-redux';
 import { Dropdown, DropdownItem, DropdownToggle, Title } from '@patternfly/react-core';
 import { CaretDownIcon } from '@patternfly/react-icons';
-import { Perspective } from '@console/plugin-sdk';
-import * as plugins from '../../plugins';
+import { Perspective, useExtensions, isPerspective } from '@console/plugin-sdk';
 import { RootState } from '../../redux';
 import { featureReducerName, getFlagsObject, FlagsObject } from '../../reducers/features';
 import { getActivePerspective } from '../../reducers/ui';
@@ -27,6 +26,7 @@ const NavHeader_: React.FC<NavHeaderProps & StateProps> = ({
   flags,
 }) => {
   const [isPerspectiveDropdownOpen, setPerspectiveDropdownOpen] = React.useState(false);
+  const perspectiveExtensions = useExtensions<Perspective>(isPerspective);
 
   const togglePerspectiveOpen = React.useCallback(() => {
     setPerspectiveDropdownOpen(!isPerspectiveDropdownOpen);
@@ -51,10 +51,10 @@ const NavHeader_: React.FC<NavHeaderProps & StateProps> = ({
       <DropdownToggle
         isOpen={isPerspectiveDropdownOpen}
         onToggle={togglePerspectiveOpen}
-        iconComponent={CaretDownIcon}
+        toggleIndicator={CaretDownIcon}
         data-test-id="perspective-switcher-toggle"
       >
-        <Title size="md">
+        <Title headingLevel="h2" size="md">
           <span className="oc-nav-header__icon">{icon}</span>
           {name}
         </Title>
@@ -63,9 +63,9 @@ const NavHeader_: React.FC<NavHeaderProps & StateProps> = ({
     [isPerspectiveDropdownOpen, togglePerspectiveOpen],
   );
 
-  const getPerspectiveItems = React.useCallback(
-    (perspectives: Perspective[]) => {
-      return perspectives.map((nextPerspective: Perspective) => (
+  const perspectiveItems = React.useMemo(
+    () =>
+      perspectiveExtensions.map((nextPerspective: Perspective) => (
         <DropdownItem
           key={nextPerspective.properties.id}
           onClick={(event: React.MouseEvent<HTMLLinkElement>) =>
@@ -74,28 +74,26 @@ const NavHeader_: React.FC<NavHeaderProps & StateProps> = ({
           isHovered={nextPerspective.properties.id === activePerspective}
           component="button"
         >
-          <Title size="md">
+          <Title headingLevel="h2" size="md" data-test-id="perspective-switcher-menu-option">
             <span className="oc-nav-header__icon">{nextPerspective.properties.icon}</span>
             {nextPerspective.properties.name}
           </Title>
         </DropdownItem>
-      ));
-    },
-    [activePerspective, onPerspectiveSelect],
+      )),
+    [activePerspective, onPerspectiveSelect, perspectiveExtensions],
   );
 
-  const perspectives = React.useMemo(() => plugins.registry.getPerspectives(), []);
   const { icon, name } = React.useMemo(
-    () => perspectives.find((p) => p.properties.id === activePerspective).properties,
-    [activePerspective, perspectives],
+    () => perspectiveExtensions.find((p) => p.properties.id === activePerspective).properties,
+    [activePerspective, perspectiveExtensions],
   );
 
   return (
-    <div className="oc-nav-header">
+    <div className="oc-nav-header" data-tour-id="tour-perspective-dropdown">
       <Dropdown
         isOpen={isPerspectiveDropdownOpen}
         toggle={renderToggle(icon, name)}
-        dropdownItems={getPerspectiveItems(perspectives)}
+        dropdownItems={perspectiveItems}
         data-test-id="perspective-switcher-menu"
       />
     </div>
