@@ -7,6 +7,8 @@ import {
   DeploymentConfigModel,
   StatefulSetModel,
   PodModel,
+  JobModel,
+  CronJobModel,
 } from '../../models';
 
 export const resourceOverviewPages = ImmutableMap<
@@ -19,12 +21,12 @@ export const resourceOverviewPages = ImmutableMap<
     ),
   )
   .set(referenceForModel(DeploymentModel), () =>
-    import('./deployment-overview' /* webpackChunkName: "deployment"*/).then(
+    import('./deployment-overview' /* webpackChunkName: "deployment-overview"*/).then(
       (m) => m.DeploymentOverviewPage,
     ),
   )
   .set(referenceForModel(DeploymentConfigModel), () =>
-    import('./deployment-config-overview' /* webpackChunkName: "deployment-config"*/).then(
+    import('./deployment-config-overview' /* webpackChunkName: "deployment-config-overview"*/).then(
       (m) => m.DeploymentConfigOverviewPage,
     ),
   )
@@ -35,4 +37,10 @@ export const resourceOverviewPages = ImmutableMap<
     import('./stateful-set-overview' /* webpackChunkName: "stateful-set"*/).then(
       (m) => m.StatefulSetOverview,
     ),
+  )
+  .set(referenceForModel(CronJobModel), () =>
+    import('./cron-job-overview' /* webpackChunkName: "cron-job"*/).then((m) => m.CronJobOverview),
+  )
+  .set(referenceForModel(JobModel), () =>
+    import('./job-overview' /* webpackChunkName: "job"*/).then((m) => m.JobOverview),
   );
